@@ -4,13 +4,13 @@ use warnings;
 use 5.024000;
 use Types::Standard qw/:all/;
 use List::UtilsBy qw/sort_by nsort_by partition_by/;
-use List::Util qw/uniq/;
+use List::MoreUtils qw/uniq/;
 use Moo;
 use Memoize;
 use Log::Any qw//;
 use DBI;
 
-our $VERSION = '0.02';
+our $VERSION = '0.03';
 
 has 'input_alphabet' => (
   is       => 'ro',
@@ -798,24 +798,24 @@ default.
 
 =over
 
-=item $self->find_or_create_state_id(@vertices)
+=item $dfa->find_or_create_state_id(@vertices)
 
 Given a list of vertices, computes a new state, adds it to the
 automaton if it does not already exist, and returns an identifier
 for the state. This is used to create a start state in the DFA.
 
-=item $self->compute_some_transitions($limit)
+=item $dfa->compute_some_transitions($limit)
 
 Computes up to C<$limit> additional transitions and returns the
 number of transitions actually computed. A return value of zero
 indicates that all transitions have been computed.
 
-=item $self->dead_state_id()
+=item $dfa->dead_state_id()
 
 Returns the state identifier for a fixed dead state (from which
 no accepting configuration can be reached).
 
-=item $self->cleanup_dead_states(\&vertices_accept)
+=item $dfa->cleanup_dead_states(\&vertices_accept)
 
 Given a code reference that takes a list of vertices and returns
 true if and only if the vertices are an accepting configuration,
@@ -897,6 +897,10 @@ L<http://rt.cpan.org/NoAuth/Bugs.html?Dist=Algorithm-ConstructDFA2>
 
 =back
 
+=head1 ACKNOWLEDGEMENTS
+
+Thanks to Slaven Rezic for bug reports.
+
 =head1 AUTHOR / COPYRIGHT / LICENSE
 
   Copyright (c) 2017-2018 Bjoern Hoehrmann <bjoern@hoehrmann.de>.
